from omniversion import Omniversion
from .. import show_dashboard

data = Omniversion("/tmp/omniversion")

show_dashboard(data)
